//
//  WDSpeedTestConfig.h
//  IWangDingSDK_SCSP
//
//  Created by maoyuxiang on 2019/4/9.
//  Copyright © 2019年 iwangding. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/**
 测速运行的类型

 - WDSpeedTestRunTypePing: Ping
 - WDSpeedTestRunTypeTraceRoute TraceRoute
 - WDSpeedTestRunTypeTCP TCP
 - WDSpeedTestRunTypeDownload: 下载
 - WDSpeedTestRunTypeUpload: 上传
 */
typedef NS_ENUM(NSInteger, WDSpeedTestRunType) {
    WDSpeedTestRunTypePing = 0,
    WDSpeedTestRunTypeTraceRoute,
    WDSpeedTestRunTypeTCP,
    WDSpeedTestRunTypeDownload,
    WDSpeedTestRunTypeUpload,
};

/**
   测速返回速率类型

 - WDSpeedTestDataInterval: 间隔速率（默认值）
 - WDSpeedTestDataAverage: 平均速率
 */
typedef NS_ENUM(NSInteger, WDSpeedTestDataType) {
    WDSpeedTestDataTypeInterval,
    WDSpeedTestDataTypeAverage,
};

/**
   测速数据采集方式

 - WDSpeedTestCatchTypeTransmit: 传递数据（默认值）
 - WDSpeedTestCatchTypeBack: 网卡背景流量数据
 */
typedef NS_ENUM(NSInteger, WDSpeedTestCatchType) {
    WDSpeedTestCatchTypeTransmit,
    WDSpeedTestCatchTypeBack
};

/**
 宽带测速的配置类， 注意：pingInterval，pingCount，downloadThreadNum，uploadThreadNum这4个参数，如果设置的值小于等于0，则使用后台获取的测速策略值
 */
@interface WDSpeedTestConfig : NSObject

#pragma mark Ping测试相关参数
/** 设置ping的timeout时间(单位ms，不能小于1000，默认值1000)*/
@property(assign, nonatomic) long pingTimeout;

/** 设置ping次数(0或负数表示不设置，默认值0)*/
@property(assign, nonatomic) NSInteger pingCount;

#pragma mark 下载测速相关参数
/** 下载测速返回速率类型(默认值 WDSpeedTestDataInterval)*/
@property(assign, nonatomic) WDSpeedTestDataType downloadBackDataType;

/** 下载测速数据采集方式(默认值 WDSpeedTestCatchTypeTransmit)*/
@property(assign, nonatomic) WDSpeedTestCatchType downloadCatchType;

/** 下载测速数据回吐间隔(单位ms，不能小于100，默认值1000)*/
@property(assign, nonatomic) NSInteger downloadBackDataTime;

/** 下载测速开启的线程数(0或负数表示不设置，默认值0)*/
@property(assign, nonatomic) NSInteger downloadThreadNum;

#pragma mark 上传测速相关参数
/** 上传测速返回速率类型(默认值 WDSpeedTestDataInterval)*/
@property(assign, nonatomic) WDSpeedTestDataType uploadBackDataType;

/** 上传测速数据采集方式(默认值 WDSpeedTestCatchTypeTransmit)*/
@property(assign, nonatomic) WDSpeedTestCatchType uploadCatchType;

/** 上传测速数据回吐间隔(单位ms，不能小于100，默认值1000)*/
@property(assign, nonatomic) NSInteger uploadBackDataTime;

/** 上传测速开启的线程数(0或负数表示不设置，默认值0)*/
@property(assign, nonatomic) NSInteger uploadThreadNum;


#pragma mark 方法

/**
 获取默认配置

 @return 默认配置
 */
+ (WDSpeedTestConfig *)defaultConfig;

@end

NS_ASSUME_NONNULL_END
